/*
 * DAC4_mcp4728.h
 *
 *  Created on: 28. mars 2022
 *      Author: oyvindteig
 */


#ifndef DAC4_MCP4728_H_
    #define DAC4_MCP4728_H_

   // NOT IMPLEMENTED, don't need to set the I2C address etc.
    typedef enum {
        DAC4_REG_GENERAL_CALL_COMMAND  = 0x00, // first byte
        DAC4_GENERAL_CALL_RESET        = 0x06, // second byte
        DAC4_GENERAL_CALL_WAKE_UP      = 0x09, // second byte
        DAC4_GENERAL_CALL_SW_UPDATE    = 0x08, // second byte
        DAC4_GENERAL_CALL_READ_ADDRESS = 0x0C  // second byte
    } i2c_adc4_reg_general_call_t;

    typedef enum {
        DAC4_REG_FAST_WRITE_COMMAND                    = 0b00000000, // 000     ONLY THIS IMPLEMENTED
        DAC4_REG_WRITE_INPUT_REG_AND_EEPROM_COMMAND_00 = 0b01000000, // 010 00
        DAC4_REG_WRITE_INPUT_REG_AND_EEPROM_COMMAND_10 = 0b01010000, // 010 10
        DAC4_REG_WRITE_INPUT_REG_AND_EEPROM_COMMAND_11 = 0b01011000, // 010 11
        DAC4_REG_WRITE_ADRRESS                         = 0b01100000, // 011
        DAC4_REG_WRITE_VREF                            = 0b10000000, // 100
        DAC4_REG_WRITE_GAIN                            = 0b11000000, // 110
        DAC4_REG_WRITE_POWERDOWN                       = 0b10100000, // 101
    } i2c_adc4_reg_address_internal_t;

    #define DAC4_POWER_DOWN_BIT_POS 4 // Above D11 when DAC4_REG_FAST_WRITE_COMMAND
    typedef enum {
        DAC4_POWER_DOWN_NORMAL = (0<<DAC4_POWER_DOWN_BIT_POS), // Only this coded, I don't need 40 nA power consumption!
        DAC4_POWER_DOWN_1K     = (1<<DAC4_POWER_DOWN_BIT_POS),
        AC4_POWER_DOWN_100K    = (2<<DAC4_POWER_DOWN_BIT_POS),
        AC4_POWER_DOWN_500K    = (3<<DAC4_POWER_DOWN_BIT_POS)
    } i2c_adc4_power_down_t;

    // For DAC4_REG_FAST_WRITE_COMMAND. Some of these are not needed teh way it's coded
    #define DAC4_NUM_BITS                12         // Whereas ONE_Q8_24 is 12 bits away = 24 (from dsp_math.h in lib_dsp)
    #define DAC4_VAL_MAX                 ((1<<DAC4_NUM_BITS)-1) // 0xFFF
    #define DAC4_MSB_MASK                0b00001111 // For [D11..D8]
    #define DAC4_POWER_DOWN_MASK         0b00110000
    #define DAC4_FAST_WRITE_COMMAND_MASK 0b11000000 // Only NEEDED IN first byte after addres byte

    #define IOF_8IN16_MSB 1
    #define IOF_8IN16_LSB 0
    //
    typedef struct {
        union {
            uint16_t data16;   // 0x8741
            uint8_t  data8[2]; // [IOF_8IN16_LSB]=41 [IOF_8IN16_MSB]=87 as expected
        } u;
    } uint_data16_arr8_t;

    typedef enum {
        DAC4_CH0_A,
        DAC4_CH1_B,
        DAC4_CH2_C,
        DAC4_CH3_D, // Scope trigger channel
        MUM_DAC4_CHANNELS
    } DAC4_index_e;

    #define DAC4_REG_FAST_WRITE_COMMAND_NUM_BITS (2 + (9 * (1 + (MUM_DAC4_CHANNELS * 2)))) // 2+(9*9)= 83
    //                                            2                      start and final stop
    //                                                 9                 8 bits + 1 ack per round
    //                                                      1            command byte
    //                                                           4 * 2 = 8 data bytes = 4 data words

    #define SCOPE_TRIGGER_ON_VAL  DAC4_VAL_MAX // Used by DAC4_CH3_D
    #define SCOPE_TRIGGER_OFF_VAL 0            // Used by DAC4_CH3_D

    typedef struct {
        unsigned       curve                     [MUM_DAC4_CHANNELS];
        bool           do_scale_ratio            [MUM_DAC4_CHANNELS];
        uint32_ratio_t scale_ratio               [MUM_DAC4_CHANNELS];
        unsigned       scale_shift_right_by_bits [MUM_DAC4_CHANNELS];
    } DAC4_context_t;

    void DAC4_fill_buffer (
            const DAC4_context_t ctx,
            i2c_uint8_t          i2c_bytes [MUM_DAC4_CHANNELS * 2]); // returned

#else
    #error NESTED .h FILE
#endif
