/*
 * DAC4_mcp4728.xc
 *
 *  Created on: 31. mars 2022
 *      Author: oyvindteig
 */

#define INCLUDES
#ifdef INCLUDES
    #include <xs1.h>
    #include <platform.h> // tile
    #include <timer.h>    // delay_milliseconds(200), XS1_TIMER_HZ etc
    #include <stdint.h>   // uint8_t
    #include <stdio.h>    // printf
    #include <string.h>   // memcpy
    #include <xccompat.h> // REFERENCE_PARAM(my_app_ports_t, my_app_ports) -> my_app_ports_t &my_app_ports
    #include <iso646.h>   // not etc.
    #include <i2c.h>
    #include <i2s.h>
    #include <dsp_fft.h>
    #include <dsp_math.h>
    #include <xassert.h>

    #include "_version.h" // First this..
    #include "_globals.h" // ..then this

    #include "param.h"
    #include "i2c_client_task.h"
    #include "maths_fix.h"

    #include "DAC4_mcp4728.h"

    #define DO_DEBUG_PRINT         0 // 0 has consequences if (USE_XSCOPE == 1)
    #define DO_DEBUG_PRINT_SPECIAL 1
    #define DO_WARNINGS            1
    #include "_print_macros_xc.h"
#endif


void DAC4_fill_buffer (
        const DAC4_context_t ctx,
        i2c_uint8_t          i2c_bytes [MUM_DAC4_CHANNELS * 2]) // returned
{
    for (unsigned ix=0; ix<MUM_DAC4_CHANNELS; ix++) {
        uint_data16_arr8_t data;
        unsigned iy = ix * 2; // 0 2 4 6

        if (ctx.do_scale_ratio[ix]) {
            // autoscales to max always (1<<DAC4_NUM_BITS)-1 = 0xFFF
            data.u.data16 = (uint16_t) downscale_by_uint32_ratio (ctx.curve[ix], ctx.scale_ratio[ix]);
        } else {
            // Top will reside between 0xFFF and its half I think
            data.u.data16 = (uint16_t) (ctx.curve[ix] >> ctx.scale_shift_right_by_bits[ix]);
        }

        // data16: 60239 > 4095 scale:1 [0]=3698920356 DC790BA4
        // data16: 50687 > 4095 scale:1 [0]=3704053716 DCC75FD4 num:4096 den:5132
        // OK mcp4728 0 max:4160 192= 0.0 0.0 0.0 FF.F
        // data16: 64508 > 4095 scale:1 [0]=3689885676 DBEF2FEC num:4096 den:4160

        if (data.u.data16 > DAC4_VAL_MAX) {
            debug_print ("data16: %u > %u scale:%u [%u]=%u %X num:%u den:%u\n",
                    data.u.data16,
                    DAC4_VAL_MAX,
                    ctx.do_scale_ratio[ix],
                    ix, ctx.curve[ix],
                    ctx.curve[ix],
                    ctx.scale_ratio[ix].num,
                    ctx.scale_ratio[ix].den);

            data.u.data16 = DAC4_VAL_MAX;
        }

        xassert (data.u.data16 <= DAC4_VAL_MAX); // 0x0FFF so four leftmost bits of IOF_8IN16_MSB are zero

        // FILL 4 BITS CONFIG and 4 BITS DATA (the bitors with zero will be optimized away)
        // DAC4_REG_FAST_WRITE_COMMAND only needed in first byte, XX in 3rd,5th,7th byte
        // THEN FILL 8 LSB BITS OF DATA
        i2c_bytes[iy]   = (data.u.data8 [IOF_8IN16_MSB] bitor DAC4_POWER_DOWN_NORMAL bitor DAC4_REG_FAST_WRITE_COMMAND);
        i2c_bytes[iy+1] =  data.u.data8 [IOF_8IN16_LSB];
    }
}

