/*
 * _Beep_dsp_handling.h
 *
 *  Created on: 8. jan. 2022
 *      Author: oyvindteig
 */


#ifndef DSP_HANDLING_H_
#define DSP_HANDLING_H_

    #define NUM_MIC_SAMPLES_REAL (1 << NUM_MIC_SAMPLES_LOG2) // 1024

    typedef struct {
        unsigned     num_samples; // The number of valid samples
        bool         is_full;
        unsigned     num_lost_overflowed;
        bool         was_late;
    } mic_samples_info_t;

    // The buffer used to be part of the above struct, but with the cast to complex array it looks better alone.
    // Both need to be sent (in send_pair) per "batch", but the overhead is about nought on this processor..
    //
    typedef struct {
        int64_t dummy_avoid_memory_error_align_below_at_double_word; // or make the array file global in the file
        union {
            // ================================================
            // Reuse of buffer, avoids ram usage and memcpy
            // with union instead of complex casts to pointers
            // ================================================

            // All these unions must have the same size. There is an
            //     xassert ((sizeof (this struct) == NUM_MIC_SAMPLES_REAL * 4));
            // in the code. There also check by the compiler at the same place

            // Fill samples into:
            //
            mic_sample_t mic_samples [NUM_MIC_SAMPLES_REAL]; // 1 * 1024

            // For:
            //     dsp_fft_bit_reverse
            //     dsp_fft_forward
            //     dsp_fft_split_spectrum
            // Instead of this (which seemed to work):
            //     dsp_complex_t (* restrict complex_array_ptr) = (dsp_complex_t(*)) buffer.u.mic_samples;
            // This cast is explained in https://www.katjaas.nl/realFFT/realFFT2.html
            // Plus in lib_dsp.pdf
            //
            dsp_complex_t complex_array [NUM_FFT_POINTS_COMPLEX]; // 2 * 512

            // After dsp_fft_split_spectrum

            // Instead of this:
            //     dsp_complex_t (* restrict w)[2] = (dsp_complex_t (*)[2])pts;
            // spelt out as (which I did have problems with the error size of array too large for the usage in my_dsp_magnitude):
            //     dsp_complex_t  (* restrict freq_spectrum)[NUM_FREQ_SPECTRA] =
            //         (dsp_complex_t (*)[NUM_FREQ_SPECTRA])buffer.u.mic_samples;
            //
            dsp_complex_t complex_half_spectra [NUM_FREQ_SPECTRA][NUM_FREQ_POINTS_REAL]; // 2 * 2 * 256
        } u;
    } mic_samples_buff_t;

    typedef bool get_next_mic_samples_buffer_t;

    // https://www.teigfam.net/oyvind/home/technology/219-my-beep-brrr-notes/#Ref16
    // NUM_SAMPLES SAMPLING_FREQ_HZ FRAME_LENGTH_MS NUM_FFT_FREQ_BINS HZ_PER_BIN
    // 8192         8000            1024            4096              1.95
    // 8192        12000            682.666..       4096              2.92
    // 4096         8000            512             2048              3.91
    // 4096        12000            341.333..       2048              5.86
    // 2048         8000            256             1024              7.81
    // 2048        12000            170.666..       1024             11.72

    #define SPECTRUM_Q_FORMAT 24
    typedef q8_24             spectrum_val_t;

    typedef struct {
        uint32_t val_at_ix; // Init is 0 (since UINT_MIN is not defined in the standard in limits.h)
        unsigned ix;
        unsigned val_new_cnt;    // Interesting
        unsigned val_stable_cnt; // Interesting
        unsigned val_aux_cnt;    // Interesting
    } uint_max_value_t; // Max is (2exp32)-1 = UINT_MAX 4294967295

    typedef struct {
        int32_t  val_at_ix; // Init is INT_MIN (limits.h)
        unsigned ix;
        unsigned val_new_cnt;    // Interesting
        unsigned val_stable_cnt; // Interesting
        unsigned val_aux_cnt;    // Interesting
    } int_max_value_t; // Max is (2exp31)-1 = INT_MAX 2147483647

    typedef struct {
        int32_t  val_at_ix; // Init is INT_MAX (limits.h)
        unsigned ix;
        unsigned val_new_cnt;    // Interesting
        unsigned val_stable_cnt; // Interesting
        unsigned val_aux_cnt;    // Interesting
    } int_min_value_t; // Min is -2exp31 = INT_MIN −2147483648

    typedef struct {
        int_max_value_t freq_max_value;
    } data_ch_results_t;

    typedef struct { // MAX_SIZEOF_NONBLOCKING_STREAMING_CHAN
        bool empty;
    } data_sch_knock_t;
    //
    #define DO_DSP_RESULTS_TO_DISPLAY true // or false (if false, forever false)

    typedef struct {
        bool empty;
    } data_ch_params_t;

    typedef struct {
        spectrum_val_t   spectrum [NUM_FREQ_POINTS_REAL];
    } data_ch_logger_t;

    // [[combinable]] // Not with ordered select
    void dsp_task_y (
            chanend           ch_out_in,
            chanend           ch_xscope_curve_out,
            streaming chanend sch_yb); // knock then data_ch_params_t and data_ch_results_t then

    void buffer_task_x (
            chanend ch_in,      // data_ch_phase0_t  then data_ch_phase3_t
            chanend ch_in_out); // get_next_mic_samples_buffer_t then mic_samples_info_t and mic_samples_info_t

    #ifndef DEBUG_DSP_ERROR_LOG
        #error include of _globals.h missing
    #endif

#else
    #error NESTED .h FILE
#endif
