/*
 * button_press.h
 *
 *  Created on: 18. mars 2015
 *      Author: teig
 */

#ifndef BUTTON_PRESS_H_
    #define BUTTON_PRESS_H_

    typedef enum {
        BUTTON_ACTION_VOID,
        BUTTON_ACTION_PRESSED,
        BUTTON_ACTION_PRESSED_FOR_LONG, // BUTTON_ACTION_PRESSED_FOR_LONG_TIMEOUT_MS
        BUTTON_ACTION_RELEASED          // Not after BUTTON_ACTION_PRESSED_FOR_LONG
    } button_action_t;

    typedef enum {long_enabled, long_disabled} long_button_enabled_e;

    typedef interface button_if_1 {
        // caused the potentially recursive call to cause error from the linker:
        // Error: Meta information. Error: lower bound could not be calculated (function is recursive?).
        //
        void button (const button_action_t button_action); // timerafter-driven

    } button_if_1;

    typedef interface button_if_2 {
        // caused the potentially recursive call to cause error from the linker:
        // Error: Meta information. Error: lower bound could not be calculated (function is recursive?).
        //
        void button (const button_action_t button_action, const unsigned button_edge_cnt); // timerafter-driven

    } button_if_2;

    typedef interface button_if_3 {
        // caused the potentially recursive call to cause error from the linker:
        // Error: Meta information. Error: lower bound could not be calculated (function is recursive?).
        //
        //[[guarded]] void button (const button_action_t button_action); // timerafter-driven
        void button (const button_action_t button_action, const unsigned button_edge_cnt, const unsigned button_noisy_time_us); // timerafter-driven

    } button_if_3;

    // If client has its own button REPEAT by holding button depressed, this should not be used
    #define BUTTON_ACTION_PRESSED_FOR_LONG_TIMEOUT_MS 10000 //10 seconds. Max 2exp31 = 2147483648 = 21.47483648 seconds (not one less)

                                   // # MIC_ARRAY
    #define IOF_BUTTON_LEFT      0 // A
    #define IOF_BUTTON_CENTER    1 // B
    #define IOF_BUTTON_RIGHT     2 // C
    #define IOF_BUTTON_FAR_RIGHT 3 // D

    #define BUTTONS_NUM_CLIENTS  4

    typedef struct {
        bool pressed_now;
        bool pressed_for_long;
        bool inhibit_released_once;
    } button_states_t;

    [[combinable]]
    void Button_Task_1 ( // No EMC considerations
            const unsigned     button_n,
            in buffered port:1 p_button,
            client button_if_1 if_button);

    [[combinable]]
    void Button_Task_2 (
            const unsigned              button_n,
            const long_button_enabled_e long_button_enabled,
            in buffered port:1          p_button,
            client button_if_2          if_button); // const unsigned button_edge_cnt added

    [[combinable]]
    void Button_Task_3 (
            const unsigned              button_n,
            const long_button_enabled_e long_button_enabled,
            in buffered port:1          p_button,
            client button_if_3          if_button); // const unsigned button_noisy_time_us added

    [[combinable]]
    void Button_Task_4 (
            const unsigned              button_n,
            const unsigned              max_button_noisy_time_us, // added
            const long_button_enabled_e long_button_enabled,
            in buffered port:1          p_button,
            client button_if_3          if_button);

    // ==========================
    // For IS_MYTARGET_MIC_ARRAY
    // ==========================

    typedef struct {
        bool pressed_now;
        bool released_now;
    } pin_states_t;

    typedef bool button_pressed_t; // true is BUTTON_PRESSED

    typedef interface pin_if_1 {
        void button_changed (const button_pressed_t button_pressed); // [[guarded]] up to version 0006
    } pin_if_1;

    [[combinable]]
    void Buttons_demux_task ( // No EMC considerations
            in buffered port:4 p_4_buttons,
            client pin_if_1    pin_if[BUTTONS_NUM_CLIENTS]);

    [[combinable]]
    void Button_task (
            const unsigned     button_n,
            server pin_if_1    if_pin,
            client button_if_1 if_button);
#else
    #error NESTED .h FILE
#endif
