/*
This is the core graphics library for all our displays, providing a common
set of graphics primitives (points, lines, circles, etc.).  It needs to be
paired with a hardware-specific library for each display device we carry
(to handle the lower-level functions).

Adafruit invests time and resources providing this open source code, please
support Adafruit & open-source hardware by purchasing products from Adafruit!

Copyright (c) 2013 Adafruit Industries.  All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

- Redistributions of source code must retain the above copyright notice,
  this list of conditions and the following disclaimer.
- Redistributions in binary form must reproduce the above copyright notice,
  this list of conditions and the following disclaimer in the documentation
  and/or other materials provided with the distribution.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
POSSIBILITY OF SUCH DAMAGE.
*/

/*
 * core_graphics_font5x8.h
 *
 *  Created on: 1. mars 2015
 *      Author: Teig
 */ \

#ifndef CORE_GRAPHICS_FONT5X8_H_
    #define CORE_GRAPHICS_FONT5X8_H_

    // Standard ASCII 5x8 font
    extern unsigned char font[];

    //{{{  Change some letters to become Norwegian

    // The font is seen as this face: (-8
    //
    // FROM
    // 0x22, 0x54, 0x54, 0x78, 0x42, /* 132 a-umlaut */
    //      84218421
    // 0x22   1   1
    // 0x54  1 1 1
    // 0x54  1 1 1
    // 0x78  1111
    // 0x42  1    1
    // TO
    // 0x20, 0x56, 0x55, 0x7A, 0x40, /* 132 a-ring */
    //      84218421
    // 0x20   1
    // 0x56  1 1 11
    // 0x55  1 1 1 1
    // 0x7A  1111 1
    // 0x40  1

    // 0x7C, 0x12, 0x17, 0x12, 0x7C, /* 143 A-ring with NO DOTS BETWEEN LINES (nicer) */
    //      1        NO DOTS HERE
    // 0x7C  11111
    // 0x12    1  1
    // 0x17    1 111
    // 0x12    1  1
    // 0x7C  11111

    // FROM
    // 0x3A, 0x44, 0x44, 0x44, 0x3A, /* 148 o-umlaut */
    //      84218421
    // 0x3A   111 1
    // 0x44  1   1
    // 0x44  1   1
    // 0x44  1   1
    // 0x3A   111 1
    // TO
    // 0xB8, 0x64, 0x54, 0x4C, 0x3A, /* 148 o-slash */
    //      84218421
    // 0xB8 1 111
    // 0x64  11  1
    // 0x54  1 1 1
    // 0x4C  1  11
    // 0x3A   111 1

    //}}}

    #define CHAR_SMILEY        2 // Alternatively 1
    #define CHAR_UP_ARROW     24 // ↑
    #define CHAR_DOWN_ARROW   25 // ↓
    #define CHAR_RIGHT_ARROW  26 // -> but nicer
    #define CHAR_LEFT_ARROW   27 // <- but nicer
    #define CHAR_aa          132 // å MODIFIED, was a-umlaut ä
    #define CHAR_AA          143 // Å MODIFIED, was A-ring (but a dot)
    #define CHAR_ae          145 // æ MODIFIED, was o-umlaut ö
    #define CHAR_AE          146 // Æ
    #define CHAR_oe          148 // ø
    #define CHAR_OE          236 // Ø
    #define CHAR_TRIPLE_BAR  239 // ≡
    #define CHAR_PLUS_MINUS  240 // ±
    #define CHAR_CIRCLE      247 // Not 176 as in https://en.wikipedia.org/wiki/Degree_symbol. See file "Drawing 8 - ASCII_FONT5X8 pictures" (Pages,PDF,JPG)

    //  Original characters, MODIFIED in ASCII_FONT5X8
    /*  0x22, 0x54, 0x54, 0x78, 0x42,   132 a-umlaut           */
    /*  0xF0, 0x28, 0x25, 0x28, 0xF0,   143 A-ring (with dot)  */
    /*  0x7C, 0x12, 0x11, 0x12, 0x7C,   143 A-ring (with dot)  */
    /*  0x3A, 0x44, 0x44, 0x44, 0x3A,   148 o-umlaut           */

    // Matching setTextSize(1) = one dot is one pixel
    // Matching setTextSize(2) = one dot is four pixels

    // Was downloaded from GitHub as "Standard ASCII 5x7 font", which is correct in a way:
    // the letter "O" has no pixel in the highest bit (lowest pixel pos), meaning it fills 5x7,
    // but some other chars have pixels "below the line". Capital A-umlaut (modified to A-ring) actually
    // starts below the line, so it gets more space available. Lots of small letters star below
    // the line, of course, like "y". Not certain about terminology, though.

    // See file "Drawing 8 - ASCII_FONT5X8 pictures" (Pages,PDF,JPG)

    #define ASCII_FONT5X8_LEN 255

    #define ASCII_FONT5X8 \
    /* ASCII_FONT5X8 first full screen [0..83]                    */ \
        0x00, 0x00, 0x00, 0x00, 0x00,   /* 000                    */ \
        0x3E, 0x5B, 0x4F, 0x5B, 0x3E,   /* 001 Face :-(           */ \
        0x3E, 0x6B, 0x4F, 0x6B, 0x3E,   /* 002 Face               */ \
        0x1C, 0x3E, 0x7C, 0x3E, 0x1C,   /* 003 Heart              */ \
        0x18, 0x3C, 0x7E, 0x3C, 0x18,   /* 004                    */ \
        0x1C, 0x57, 0x7D, 0x57, 0x1C,   /* 005                    */ \
        0x1C, 0x5E, 0x7F, 0x5E, 0x1C,   /* 006                    */ \
        0x00, 0x18, 0x3C, 0x18, 0x00,   /* 007                    */ \
        0xFF, 0xE7, 0xC3, 0xE7, 0xFF,   /* 008                    */ \
        0x00, 0x18, 0x24, 0x18, 0x00,   /* 009 Circle             */ \
        0xFF, 0xE7, 0xDB, 0xE7, 0xFF,   /* 010                    */ \
        0x30, 0x48, 0x3A, 0x06, 0x0E,   /* 011                    */ \
        0x26, 0x29, 0x79, 0x29, 0x26,   /* 012                    */ \
        0x40, 0x7F, 0x05, 0x05, 0x07,   /* 013                    */ \
        0x40, 0x7F, 0x05, 0x25, 0x3F,   /* 014                    */ \
        0x5A, 0x3C, 0xE7, 0x3C, 0x5A,   /* 015                    */ \
        0x7F, 0x3E, 0x1C, 0x1C, 0x08,   /* 016                    */ \
        0x08, 0x1C, 0x1C, 0x3E, 0x7F,   /* 017                    */ \
        0x14, 0x22, 0x7F, 0x22, 0x14,   /* 018                    */ \
        0x5F, 0x5F, 0x00, 0x5F, 0x5F,   /* 019                    */ \
        0x06, 0x09, 0x7F, 0x01, 0x7F,   /* 020                    */ \
        0x00, 0x66, 0x89, 0x95, 0x6A,   /* 021                    */ \
        0x60, 0x60, 0x60, 0x60, 0x60,   /* 022                    */ \
        0x94, 0xA2, 0xFF, 0xA2, 0x94,   /* 023                    */ \
        0x08, 0x04, 0x7E, 0x04, 0x08,   /* 024 Arrow up           */ \
        0x10, 0x20, 0x7E, 0x20, 0x10,   /* 025 Arrow down         */ \
        0x08, 0x08, 0x2A, 0x1C, 0x08,   /* 026 Arrow right        */ \
        0x08, 0x1C, 0x2A, 0x08, 0x08,   /* 027 Arrow left         */ \
        0x1E, 0x10, 0x10, 0x10, 0x10,   /* 028                    */ \
        0x0C, 0x1E, 0x0C, 0x1E, 0x0C,   /* 029                    */ \
        0x30, 0x38, 0x3E, 0x38, 0x30,   /* 030                    */ \
        0x06, 0x0E, 0x3E, 0x0E, 0x06,   /* 031 !                  */ \
        0x00, 0x00, 0x00, 0x00, 0x00,   /* 032                    */ \
        0x00, 0x00, 0x5F, 0x00, 0x00,   /* 033                    */ \
        0x00, 0x07, 0x00, 0x07, 0x00,   /* 034                    */ \
        0x14, 0x7F, 0x14, 0x7F, 0x14,   /* 035                    */ \
        0x24, 0x2A, 0x7F, 0x2A, 0x12,   /* 036                    */ \
        0x23, 0x13, 0x08, 0x64, 0x62,   /* 037                    */ \
        0x36, 0x49, 0x56, 0x20, 0x50,   /* 038                    */ \
        0x00, 0x08, 0x07, 0x03, 0x00,   /* 039                    */ \
        0x00, 0x1C, 0x22, 0x41, 0x00,   /* 040                    */ \
        0x00, 0x41, 0x22, 0x1C, 0x00,   /* 041                    */ \
        0x2A, 0x1C, 0x7F, 0x1C, 0x2A,   /* 042                    */ \
        0x08, 0x08, 0x3E, 0x08, 0x08,   /* 043                    */ \
        0x00, 0x80, 0x70, 0x30, 0x00,   /* 044                    */ \
        0x08, 0x08, 0x08, 0x08, 0x08,   /* 045                    */ \
        0x00, 0x00, 0x60, 0x60, 0x00,   /* 046                    */ \
        0x20, 0x10, 0x08, 0x04, 0x02,   /* 047                    */ \
        0x3E, 0x51, 0x49, 0x45, 0x3E,   /* 048                    */ \
        0x00, 0x42, 0x7F, 0x40, 0x00,   /* 049                    */ \
        0x72, 0x49, 0x49, 0x49, 0x46,   /* 050                    */ \
        0x21, 0x41, 0x49, 0x4D, 0x33,   /* 051                    */ \
        0x18, 0x14, 0x12, 0x7F, 0x10,   /* 052                    */ \
        0x27, 0x45, 0x45, 0x45, 0x39,   /* 053                    */ \
        0x3C, 0x4A, 0x49, 0x49, 0x31,   /* 054                    */ \
        0x41, 0x21, 0x11, 0x09, 0x07,   /* 055                    */ \
        0x36, 0x49, 0x49, 0x49, 0x36,   /* 056                    */ \
        0x46, 0x49, 0x49, 0x29, 0x1E,   /* 057                    */ \
        0x00, 0x00, 0x14, 0x00, 0x00,   /* 058                    */ \
        0x00, 0x40, 0x34, 0x00, 0x00,   /* 059                    */ \
        0x00, 0x08, 0x14, 0x22, 0x41,   /* 060                    */ \
        0x14, 0x14, 0x14, 0x14, 0x14,   /* 061                    */ \
        0x00, 0x41, 0x22, 0x14, 0x08,   /* 062                    */ \
        0x02, 0x01, 0x59, 0x09, 0x06,   /* 063                    */ \
        0x3E, 0x41, 0x5D, 0x59, 0x4E,   /* 064                    */ \
        0x7C, 0x12, 0x11, 0x12, 0x7C,   /* 065 A                  */ \
        0x7F, 0x49, 0x49, 0x49, 0x36,   /* 066                    */ \
        0x3E, 0x41, 0x41, 0x41, 0x22,   /* 067                    */ \
        0x7F, 0x41, 0x41, 0x41, 0x3E,   /* 068                    */ \
        0x7F, 0x49, 0x49, 0x49, 0x41,   /* 069                    */ \
        0x7F, 0x09, 0x09, 0x09, 0x01,   /* 070                    */ \
        0x3E, 0x41, 0x41, 0x51, 0x73,   /* 071                    */ \
        0x7F, 0x08, 0x08, 0x08, 0x7F,   /* 072                    */ \
        0x00, 0x41, 0x7F, 0x41, 0x00,   /* 073                    */ \
        0x20, 0x40, 0x41, 0x3F, 0x01,   /* 074                    */ \
        0x7F, 0x08, 0x14, 0x22, 0x41,   /* 075                    */ \
        0x7F, 0x40, 0x40, 0x40, 0x40,   /* 076                    */ \
        0x7F, 0x02, 0x1C, 0x02, 0x7F,   /* 077                    */ \
        0x7F, 0x04, 0x08, 0x10, 0x7F,   /* 078                    */ \
        0x3E, 0x41, 0x41, 0x41, 0x3E,   /* 079 O                  */ \
        0x7F, 0x09, 0x09, 0x09, 0x06,   /* 080                    */ \
        0x3E, 0x41, 0x51, 0x21, 0x5E,   /* 081                    */ \
        0x7F, 0x09, 0x19, 0x29, 0x46,   /* 082                    */ \
        0x26, 0x49, 0x49, 0x49, 0x32,   /* 083                    */ \
        \
    /* ASCII_FONT5X8 second full screen [84..167]                 */ \
        0x03, 0x01, 0x7F, 0x01, 0x03,   /* 084                    */ \
        0x3F, 0x40, 0x40, 0x40, 0x3F,   /* 085                    */ \
        0x1F, 0x20, 0x40, 0x20, 0x1F,   /* 086                    */ \
        0x3F, 0x40, 0x38, 0x40, 0x3F,   /* 087                    */ \
        0x63, 0x14, 0x08, 0x14, 0x63,   /* 088                    */ \
        0x03, 0x04, 0x78, 0x04, 0x03,   /* 089                    */ \
        0x61, 0x59, 0x49, 0x4D, 0x43,   /* 090                    */ \
        0x00, 0x7F, 0x41, 0x41, 0x41,   /* 091                    */ \
        0x02, 0x04, 0x08, 0x10, 0x20,   /* 092                    */ \
        0x00, 0x41, 0x41, 0x41, 0x7F,   /* 093                    */ \
        0x04, 0x02, 0x01, 0x02, 0x04,   /* 094                    */ \
        0x40, 0x40, 0x40, 0x40, 0x40,   /* 095                    */ \
        0x00, 0x03, 0x07, 0x08, 0x00,   /* 096                    */ \
        0x20, 0x54, 0x54, 0x78, 0x40,   /* 097                    */ \
        0x7F, 0x28, 0x44, 0x44, 0x38,   /* 098                    */ \
        0x38, 0x44, 0x44, 0x44, 0x28,   /* 099                    */ \
        0x38, 0x44, 0x44, 0x28, 0x7F,   /* 100                    */ \
        0x38, 0x54, 0x54, 0x54, 0x18,   /* 101                    */ \
        0x00, 0x08, 0x7E, 0x09, 0x02,   /* 102                    */ \
        0x18, 0xA4, 0xA4, 0x9C, 0x78,   /* 103                    */ \
        0x7F, 0x08, 0x04, 0x04, 0x78,   /* 104                    */ \
        0x00, 0x44, 0x7D, 0x40, 0x00,   /* 105                    */ \
        0x20, 0x40, 0x40, 0x3D, 0x00,   /* 106                    */ \
        0x7F, 0x10, 0x28, 0x44, 0x00,   /* 107                    */ \
        0x00, 0x41, 0x7F, 0x40, 0x00,   /* 108                    */ \
        0x7C, 0x04, 0x78, 0x04, 0x78,   /* 109                    */ \
        0x7C, 0x08, 0x04, 0x04, 0x78,   /* 110                    */ \
        0x38, 0x44, 0x44, 0x44, 0x38,   /* 111                    */ \
        0xFC, 0x18, 0x24, 0x24, 0x18,   /* 112                    */ \
        0x18, 0x24, 0x24, 0x18, 0xFC,   /* 113                    */ \
        0x7C, 0x08, 0x04, 0x04, 0x08,   /* 114                    */ \
        0x48, 0x54, 0x54, 0x54, 0x24,   /* 115                    */ \
        0x04, 0x04, 0x3F, 0x44, 0x24,   /* 116                    */ \
        0x3C, 0x40, 0x40, 0x20, 0x7C,   /* 117                    */ \
        0x1C, 0x20, 0x40, 0x20, 0x1C,   /* 118                    */ \
        0x3C, 0x40, 0x30, 0x40, 0x3C,   /* 119                    */ \
        0x44, 0x28, 0x10, 0x28, 0x44,   /* 120                    */ \
        0x4C, 0x90, 0x90, 0x90, 0x7C,   /* 121  y                 */ \
        0x44, 0x64, 0x54, 0x4C, 0x44,   /* 122                    */ \
        0x00, 0x08, 0x36, 0x41, 0x00,   /* 123                    */ \
        0x00, 0x00, 0x77, 0x00, 0x00,   /* 124                    */ \
        0x00, 0x41, 0x36, 0x08, 0x00,   /* 125                    */ \
        0x02, 0x01, 0x02, 0x04, 0x02,   /* 126 ~                  */ \
        0x3C, 0x26, 0x23, 0x26, 0x3C,   /* 127                    */ \
        0x1E, 0xA1, 0xA1, 0x61, 0x12,   /* 128                    */ \
        0x3A, 0x40, 0x40, 0x20, 0x7A,   /* 129                    */ \
        0x38, 0x54, 0x54, 0x55, 0x59,   /* 130                    */ \
        0x21, 0x55, 0x55, 0x79, 0x41,   /* 131                    */ \
        0x20, 0x56, 0x55, 0x7A, 0x40,   /* 132 CHAR_aa   MODIFIED */ \
        0x21, 0x55, 0x54, 0x78, 0x40,   /* 133                    */ \
        0x20, 0x54, 0x55, 0x79, 0x40,   /* 134                    */ \
        0x0C, 0x1E, 0x52, 0x72, 0x12,   /* 135                    */ \
        0x39, 0x55, 0x55, 0x55, 0x59,   /* 136                    */ \
        0x39, 0x54, 0x54, 0x54, 0x59,   /* 137                    */ \
        0x39, 0x55, 0x54, 0x54, 0x58,   /* 138                    */ \
        0x00, 0x00, 0x45, 0x7C, 0x41,   /* 139                    */ \
        0x00, 0x02, 0x45, 0x7D, 0x42,   /* 140                    */ \
        0x00, 0x01, 0x45, 0x7C, 0x40,   /* 141                    */ \
        0x7D, 0x12, 0x11, 0x12, 0x7D,   /* 142 A-umlaut           */ \
        0x7C, 0x12, 0x17, 0x12, 0x7C,   /* 143 CHAR_AA   MODIFIED */ \
        0x7C, 0x54, 0x55, 0x45, 0x00,   /* 144                    */ \
        0x20, 0x54, 0x54, 0x7C, 0x54,   /* 145 CHAR_ae            */ \
        0x7C, 0x0A, 0x09, 0x7F, 0x49,   /* 146 CHAR_AE            */ \
        0x32, 0x49, 0x49, 0x49, 0x32,   /* 147                    */ \
        0xB8, 0x64, 0x54, 0x4C, 0x3A,   /* 148 CHAR_oe   MODIFIED */ \
        0x32, 0x4A, 0x48, 0x48, 0x30,   /* 149                    */ \
        0x3A, 0x41, 0x41, 0x21, 0x7A,   /* 150                    */ \
        0x3A, 0x42, 0x40, 0x20, 0x78,   /* 151                    */ \
        0x00, 0x9D, 0xA0, 0xA0, 0x7D,   /* 152                    */ \
        0x3D, 0x42, 0x42, 0x42, 0x3D,   /* 153 O-umlaut           */ \
        0x3D, 0x40, 0x40, 0x40, 0x3D,   /* 154                    */ \
        0x3C, 0x24, 0xFF, 0x24, 0x24,   /* 155                    */ \
        0x48, 0x7E, 0x49, 0x43, 0x66,   /* 156                    */ \
        0x2B, 0x2F, 0xFC, 0x2F, 0x2B,   /* 157                    */ \
        0xFF, 0x09, 0x29, 0xF6, 0x20,   /* 158                    */ \
        0xC0, 0x88, 0x7E, 0x09, 0x03,   /* 159                    */ \
        0x20, 0x54, 0x54, 0x79, 0x41,   /* 160                    */ \
        0x00, 0x00, 0x44, 0x7D, 0x41,   /* 161                    */ \
        0x30, 0x48, 0x48, 0x4A, 0x32,   /* 162                    */ \
        0x38, 0x40, 0x40, 0x22, 0x7A,   /* 163                    */ \
        0x00, 0x7A, 0x0A, 0x0A, 0x72,   /* 164                    */ \
        0x7D, 0x0D, 0x19, 0x31, 0x7D,   /* 165                    */ \
        0x26, 0x29, 0x29, 0x2F, 0x28,   /* 166                    */ \
        0x26, 0x29, 0x29, 0x29, 0x26,   /* 167                    */ \
        \
    /* ASCII_FONT5X8 third full screen [168..251]                 */ \
        0x30, 0x48, 0x4D, 0x40, 0x20,   /* 168                    */ \
        0x38, 0x08, 0x08, 0x08, 0x08,   /* 169                    */ \
        0x08, 0x08, 0x08, 0x08, 0x38,   /* 170                    */ \
        0x2F, 0x10, 0xC8, 0xAC, 0xBA,   /* 171                    */ \
        0x2F, 0x10, 0x28, 0x34, 0xFA,   /* 172                    */ \
        0x00, 0x00, 0x7B, 0x00, 0x00,   /* 173                    */ \
        0x08, 0x14, 0x2A, 0x14, 0x22,   /* 174 Double arrow left  */ \
        0x22, 0x14, 0x2A, 0x14, 0x08,   /* 175 Double arrow right */ \
        0xAA, 0x00, 0x55, 0x00, 0xAA,   /* 176                    */ \
        0xAA, 0x55, 0xAA, 0x55, 0xAA,   /* 177                    */ \
        0x00, 0x00, 0x00, 0xFF, 0x00,   /* 178 Vertical           */ \
        0x10, 0x10, 0x10, 0xFF, 0x00,   /* 179                    */ \
        0x14, 0x14, 0x14, 0xFF, 0x00,   /* 180                    */ \
        0x10, 0x10, 0xFF, 0x00, 0xFF,   /* 181                    */ \
        0x10, 0x10, 0xF0, 0x10, 0xF0,   /* 182                    */ \
        0x14, 0x14, 0x14, 0xFC, 0x00,   /* 183                    */ \
        0x14, 0x14, 0xF7, 0x00, 0xFF,   /* 184                    */ \
        0x00, 0x00, 0xFF, 0x00, 0xFF,   /* 185 Double vertical    */ \
        0x14, 0x14, 0xF4, 0x04, 0xFC,   /* 186                    */ \
        0x14, 0x14, 0x17, 0x10, 0x1F,   /* 187                    */ \
        0x10, 0x10, 0x1F, 0x10, 0x1F,   /* 188                    */ \
        0x14, 0x14, 0x14, 0x1F, 0x00,   /* 189                    */ \
        0x10, 0x10, 0x10, 0xF0, 0x00,   /* 190                    */ \
        0x00, 0x00, 0x00, 0x1F, 0x10,   /* 191                    */ \
        0x10, 0x10, 0x10, 0x1F, 0x10,   /* 192                    */ \
        0x10, 0x10, 0x10, 0xF0, 0x10,   /* 193                    */ \
        0x00, 0x00, 0x00, 0xFF, 0x10,   /* 194                    */ \
        0x10, 0x10, 0x10, 0x10, 0x10,   /* 195                    */ \
        0x10, 0x10, 0x10, 0xFF, 0x10,   /* 196                    */ \
        0x00, 0x00, 0x00, 0xFF, 0x14,   /* 197                    */ \
        0x00, 0x00, 0xFF, 0x00, 0xFF,   /* 198                    */ \
        0x00, 0x00, 0x1F, 0x10, 0x17,   /* 199                    */ \
        0x00, 0x00, 0xFC, 0x04, 0xF4,   /* 200                    */ \
        0x14, 0x14, 0x17, 0x10, 0x17,   /* 201                    */ \
        0x14, 0x14, 0xF4, 0x04, 0xF4,   /* 202                    */ \
        0x00, 0x00, 0xFF, 0x00, 0xF7,   /* 203                    */ \
        0x14, 0x14, 0x14, 0x14, 0x14,   /* 204                    */ \
        0x14, 0x14, 0xF7, 0x00, 0xF7,   /* 205                    */ \
        0x14, 0x14, 0x14, 0x17, 0x14,   /* 206                    */ \
        0x10, 0x10, 0x1F, 0x10, 0x1F,   /* 207                    */ \
        0x14, 0x14, 0x14, 0xF4, 0x14,   /* 208                    */ \
        0x10, 0x10, 0xF0, 0x10, 0xF0,   /* 209                    */ \
        0x00, 0x00, 0x1F, 0x10, 0x1F,   /* 210                    */ \
        0x00, 0x00, 0x00, 0x1F, 0x14,   /* 211                    */ \
        0x00, 0x00, 0x00, 0xFC, 0x14,   /* 212                    */ \
        0x00, 0x00, 0xF0, 0x10, 0xF0,   /* 213                    */ \
        0x10, 0x10, 0xFF, 0x10, 0xFF,   /* 214                    */ \
        0x14, 0x14, 0x14, 0xFF, 0x14,   /* 215                    */ \
        0x10, 0x10, 0x10, 0x1F, 0x00,   /* 216                    */ \
        0x00, 0x00, 0x00, 0xF0, 0x10,   /* 217                    */ \
        0xFF, 0xFF, 0xFF, 0xFF, 0xFF,   /* 218                    */ \
        0xF0, 0xF0, 0xF0, 0xF0, 0xF0,   /* 219                    */ \
        0xFF, 0xFF, 0xFF, 0x00, 0x00,   /* 220                    */ \
        0x00, 0x00, 0x00, 0xFF, 0xFF,   /* 221                    */ \
        0x0F, 0x0F, 0x0F, 0x0F, 0x0F,   /* 222                    */ \
        0x38, 0x44, 0x44, 0x38, 0x44,   /* 223                    */ \
        0xFC, 0x4A, 0x4A, 0x4A, 0x34,   /* 224 sharp-s, beta      */ \
        0x7E, 0x02, 0x02, 0x06, 0x06,   /* 225                    */ \
        0x02, 0x7E, 0x02, 0x7E, 0x02,   /* 226                    */ \
        0x63, 0x55, 0x49, 0x41, 0x63,   /* 227                    */ \
        0x38, 0x44, 0x44, 0x3C, 0x04,   /* 228                    */ \
        0x40, 0x7E, 0x20, 0x1E, 0x20,   /* 229                    */ \
        0x06, 0x02, 0x7E, 0x02, 0x02,   /* 230                    */ \
        0x99, 0xA5, 0xE7, 0xA5, 0x99,   /* 231                    */ \
        0x1C, 0x2A, 0x49, 0x2A, 0x1C,   /* 232                    */ \
        0x4C, 0x72, 0x01, 0x72, 0x4C,   /* 233                    */ \
        0x30, 0x4A, 0x4D, 0x4D, 0x30,   /* 234                    */ \
        0x30, 0x48, 0x78, 0x48, 0x30,   /* 235                    */ \
        0xBC, 0x62, 0x5A, 0x46, 0x3D,   /* 236 CHAR_OE            */ \
        0x3E, 0x49, 0x49, 0x49, 0x00,   /* 237                    */ \
        0x7E, 0x01, 0x01, 0x01, 0x7E,   /* 238                    */ \
        0x2A, 0x2A, 0x2A, 0x2A, 0x2A,   /* 239                    */ \
        0x44, 0x44, 0x5F, 0x44, 0x44,   /* 240                    */ \
        0x40, 0x51, 0x4A, 0x44, 0x40,   /* 241                    */ \
        0x40, 0x44, 0x4A, 0x51, 0x40,   /* 242                    */ \
        0x00, 0x00, 0xFF, 0x01, 0x03,   /* 243                    */ \
        0xE0, 0x80, 0xFF, 0x00, 0x00,   /* 244                    */ \
        0x08, 0x08, 0x6B, 0x6B, 0x08,   /* 245                    */ \
        0x36, 0x12, 0x36, 0x24, 0x36,   /* 246                    */ \
        0x06, 0x0F, 0x09, 0x0F, 0x06,   /* 247 Deg circle thick   */ \
        0x00, 0x00, 0x18, 0x18, 0x00,   /* 248                    */ \
        0x00, 0x00, 0x10, 0x10, 0x00,   /* 249                    */ \
        0x30, 0x40, 0xFF, 0x01, 0x01,   /* 250                    */ \
        0x00, 0x1F, 0x01, 0x01, 0x1E,   /* 251                    */ \
        \
    /* ASCII_FONT5X8 only two visible chars left [252..254]       */ \
        0x00, 0x19, 0x1D, 0x17, 0x12,   /* 252                    */ \
        0x00, 0x3C, 0x3C, 0x3C, 0x3C,   /* 253                    */ \
        0x00, 0x00, 0x00, 0x00, 0x00    /* 254 (black)            */

#else
    #error NESTED .h FILE
#endif

