/*
 * i2c_client_task.h
 *
 *  Created on: 27. feb. 2015
 *      Author: Teig
 */

#ifndef I2C_ICLIENT_TASK_H_
    #define I2C_ICLIENT_TASK_H_

    #if (IS_MYTARGET==IS_MYTARGET_STARTKIT)
        #error Not in this project
    #elif (IS_MYTARGET==IS_MYTARGET_XCORE_200_EXPLORER)
        #error Not in this project

        typedef enum i2c_dev_address_internal_e {
            I2C_ADDRESS_OF_ACCELEROMETER_AND_MAGNETOMETER = 0x1E, // FXOS8700CQ BMG160 3-axis gyroscope sensor
                                                                  // NOT modifiable plus hardwired on XMOS XCORE-200 EXPLORERKIT
            I2C_ADDRESS_OF_DISPLAY                        = 0x3C, // UG-2832HSWEG02 with chip SSD1306 from Univision Technology Inc. Adafruit 931
            I2C_ADDRESS_OF_GYROSCOPE_BMG160               = 0x68, // BMG160  FXOS8700CQ Digital Sensor - 3D Accelerometer (2g/4g/8g) + 3D Magnetometer
                                                                  // NOT modifiable plus hardwired on XMOS XCORE-200 EXPLORERKIT
                                                                  // Observe that CHRONODOT has same address 0x68, also hard wired! So cannot coexist on same I2C bus
            I2C_ADDRESS_OF_PORT_EXPANDER                  = 0x20  // 0x20 Lines: 0  0  0 [0x20:000]->[0x27:111] MCP23008
        } i2c_dev_address_internal_e; // i2c_dev_address_7bits_t

    #elif (IS_MYTARGET==IS_MYTARGET_XCORE_XA_MODULE)
        #error Not in this project
    #elif (IS_MYTARGET == IS_MYTARGET_MIC_ARRAY)

        #define I2C_MASTER_ONE_CLIENT 1
        //
        typedef enum i2c_master_one_client_e { // MUST BE AN ARRAY EVEN IF 1
            I2C_MASTER_IOF_SINGLE_CLIENT = 0 // Only use here in i2c_client_task.xc
        } i2c_master_one_client_e;

        #define I2C_GENERAL_NUM_CLIENTS 2 // only use in main.xc
        //
        typedef enum i2c_general_iof_client_e {
            I2C_GENERAL_IOF_ICLIENT_0, // only use in main.xc
            I2C_GENERAL_IOF_ICLIENT_1  // only use in main.xc
        } i2c_general_iof_client_e;

        // Data sheet and scope "sees" 8 bits, but [bit7..bit0].bit0 = R(1)/W(0)
        // lib_i2c params device_addr is always 7 bits, so I have called it i2c_dev_address_7bits_t
        #define I2C_SHIFT_BITS 1
        //
        typedef enum i2c_dev_address_internal_e {
            //                                                          ## For i2c_dev_address_7bits_t
            I2C_ADDRESS_OF_DISPLAY       = (0x7A>>I2C_SHIFT_BITS), // 0x3C UG-2864HSWEG01 with chip SSD1306 from Univision Technology Inc. 128x64 OLED. Adafruit 326
                                                                   //      128 x 64 size OLEDs (or changing the I2C address)
                                                                   //      https://learn.adafruit.com/monochrome-oled-breakouts
            I2C_ADDRESS_OF_PORT_EXPANDER = (0x40>>I2C_SHIFT_BITS), // 0x20 Lines: 0  0  0 [0x40:0000]->[0x4E:1110] MCP23008
            I2C_ADDRESS_OF_DAC4          = (0xC0>>I2C_SHIFT_BITS)  // 0x3D * Microchip MCP4728 on MikroElektronika DAC 4 CLICK
                                                                   //        MIKROE-3707 at https://www.mikroe.com/dac-4-click
                                                                   //      * Also used by Adafruit MCP4728 Quad DAC with EEPROM - STEMMA QT / Qwiic
                                                                   //        https://www.adafruit.com/product/4470
                                                                   //      * The address "000" is default but may be modified by
                                                                   //        writing to the internal EEPROM. I haven't supported this
                                                                   //        "general call" concept with 0x00 in the first byte etc.
        } i2c_dev_address_internal_e;

    #else
        #error TARGET NOT DEFINED
    #endif

    #define LEN_I2C_SUBADDRESS 1 // Most often some register address after the device address i2c_dev_address_internal_e
    #define IOF_I2C_SUBADDRESS 0
    typedef uint8_t i2c_uint8_t;

    // if_i2c_display_command merged with the below for v0619
    typedef interface i2c_general_commands_if {
        
        bool write_display_ok (
                const i2c_dev_address_7bits_t  dev_addr,
                const i2c_reg_address_t        reg_addr,
                const unsigned char            data[],
                const unsigned                 nbytes);

        bool write_reg_ok (
                const i2c_dev_address_7bits_t  dev_addr,
                const i2c_uint8_t              data[], // reg_addr followed by data
                static const unsigned          nbytes); // must include space for LEN_I2C_SUBADDRESS, if needed

        {bool, uint8_t} read_reg_ok (
                const i2c_dev_address_7bits_t  dev_addr,
                const i2c_uint8_t              reg_addr);

    } i2c_general_commands_if;

  
    // MUX/DEMUX for i2c_master plus display handling etc.
    //
    [[combinable]]
    void I2C_Client_Task (
            server i2c_general_commands_if if_i2c_general_commands [I2C_GENERAL_NUM_CLIENTS],
            client i2c_master_if           if_i2c[I2C_MASTER_ONE_CLIENT]); // synchronous

    // MUX/DEMUX for i2c_master plus display handling etc.
    //
    [[combinable]]
    void I2C_Client_Task_simpler (
            server i2c_general_commands_if if_i2c_general_commands,
            client i2c_master_if           if_i2c[I2C_MASTER_ONE_CLIENT]); // synchronous

#else
    #error NESTED .h FILE
#endif

