// Much from "Copyright (c) 2015-2016, XMOS Ltd, All rights reserved"
//
// ======================================================
// See "mic_array_conf.h" in lib_mic_array user guide PDF
// ======================================================
// Teig: Taken from AN00220

#ifndef MIC_ARRAY_CONF_H_
    #define MIC_ARRAY_CONF_H_

    #ifndef APPLICATION_NOTE
        #error -DAPPLICATION_NOTE not defined in makefile
    #elif (WARNINGS==1)
        #if (APPLICATION_NOTE == 219)
            #warning AN00219 config inspired // AN00219_headset_output.xc
        #elif (APPLICATION_NOTE == 220)
            #warning AN00220 config inspired // AN00220_app_phase_aligned_example.xc
        #else
            #error Wrong value
        #endif
    #endif

    // =============================
    // FOR lib_mic_array IN:
    //    decimate_to_pcm_4ch.S asm
    //      mic_array_frame.h
    //        pdm_rx.S asm
    //
    #if (APPLICATION_NOTE == 219)                  // AN00219 config inspired
        // AN00219 ORIGINAL VALUES (same as 220)
        //         MIC_ARRAY_MAX_FRAME_SIZE_LOG2 0
        //         MIC_ARRAY_NUM_MICS            8
        //         MIC_ARRAY_FIXED_GAIN          4
        #define    MIC_ARRAY_MAX_FRAME_SIZE_LOG2 0 // Defines MIC_ARRAY_NUM_SAMPLES_PER_MIC in audio.data
        //
        #define    MIC_ARRAY_NUM_MICS_LOG2       3 // 2exp3 = 8 = MIC_ARRAY_NUM_MICS
        #define    MIC_ARRAY_NUM_MICS                         8 // Must have "8 mics" (=7) since directive
    #elif (APPLICATION_NOTE == 220)                // AN00220 config inspired
        // AN00220 ORIGINAL VALUES (same as 219)
        //         MIC_ARRAY_MAX_FRAME_SIZE_LOG2 0
        //         MIC_ARRAY_NUM_MICS            8
        #define    MIC_ARRAY_MAX_FRAME_SIZE_LOG2 0 // Defines MIC_ARRAY_NUM_SAMPLES_PER_MIC in audio.data (AN00219)
        //
        #define    MIC_ARRAY_NUM_MICS_LOG2       3 // 2exp3 = 8 = MIC_ARRAY_NUM_MICS
        #define    MIC_ARRAY_NUM_MICS                         8 //
    #elif (APPLICATION_NOTE == NONE)
        #define    MIC_ARRAY_MAX_FRAME_SIZE_LOG2 0 // Defines MIC_ARRAY_NUM_SAMPLES_PER_MIC in audio.data
        //
        #define    MIC_ARRAY_NUM_MICS_LOG2       3 // 2exp3 = 8 = MIC_ARRAY_NUM_MICS
        #define    MIC_ARRAY_NUM_MICS                         8 // Must have "8 mics" (=7) since directive
    #else
        #error APPLICATION_NOTE not defined in Makefile
    #endif

    //       # MIC_ARRAY_MAX_FRAME_SIZE_LOG2
    // 2 exp(0)  =    1 MIC_ARRAY_NUM_SAMPLES_PER_MIC sample  per microphone in audio.data in example (AN00219)
    // 2 exp(1)  =    2 MIC_ARRAY_NUM_SAMPLES_PER_MIC samples per microphone in audio.data in example
    // 2 exp(2)  =    4 MIC_ARRAY_NUM_SAMPLES_PER_MIC samples per microphone in audio.data in example
    // 2 exp(3)  =    8 MIC_ARRAY_NUM_SAMPLES_PER_MIC samples per microphone in audio.data in example (AN00220)
    // ...
    // 2 exp(13) = 8192 MIC_ARRAY_NUM_SAMPLES_PER_MIC samples per microphone in audio.data in example

    // The four channel decimators (mic_array_pdm_rx()) output frames of either
    // time domain audio or FFT ready audio prepared for an FFT. The define
    // MIC_ARRAY_MAX_FRAME_SIZE_LOG2 (found in mic_array_conf.h) should be used
    // to allocate the arrays to store the frames. This means that all frames
    // structures will allocate enough memory to allow for a frame size of
    // two to the power of MIC_ARRAY_MAX_FRAME_SIZE_LOG2 regardless of the size
    // used in the decimator_config_common.
    // It is recommended that the frame_size_log2 field of decimator_config_common
    // is always set to MIC_ARRAY_MAX_FRAME_SIZE_LOG2. Equally, the define MIC_ARRAY_NUM_MICS
    // is used for allocating the memory for the frame structure. This must be set to a multiple of 4.

    // The mic_array board has 7 Infineon IM69D130 MEMS microphones
    // "Count of microphones(channels) must be set to a multiple of 4", ie 4 or 8

    // If the decimation factor is changed the the coefs_array of mic_array_decimator_config_t
    // must also be changed. Done below

    /* ========================================================================
     * THE REST OF THIS FILE IS PICKED UP BY APPLICATION IF lib_mic_array USED
     * Author: teig
     */

    // ================
    // HEADSET_OUT_PART
    // ================

    #define TEST_SINE_480HZ 0 // 0 standard input from mics
                              // 1 from sine table, 480Hz exactly only if SAMPLING_FREQUENCY_HZ is 48000
                              // Observe SINE_480HZ_DIV_FACTOR

    #if (APPLICATION_NOTE == 219)
        #define USE_BEAMFORMING   1 // Always associate with MIC_ARRAY_NUM_MICS==8. Meaningless with TEST_SINE_480HZ
        #define DECIMATION_FACTOR 2 // 48 kHz
    #elif (APPLICATION_NOTE == 220)
        #define USE_BEAMFORMING   0 // Always associate with MIC_ARRAY_NUM_MICS==4
        #define DECIMATION_FACTOR 6 // 16 kHz
    #elif (APPLICATION_NOTE == NONE)
        #define USE_BEAMFORMING    0 // Always associate with MIC_ARRAY_NUM_MICS==8. Meaningless with TEST_SINE_480HZ
        #define DECIMATION_FACTOR 12 // 8 kHz
    #endif

    #define MIC_ARRAY_NUM_SAMPLES_PER_MIC (1 << MIC_ARRAY_MAX_FRAME_SIZE_LOG2) // 1 (for 219), 2, 4, 8..

    #define DO_WAITS_IN_MIC_ARRAY_GET_NEXT_TIME_DOMAIN_FRAME 0 // 0: do some wait in task first
                                                               // 1: wait in mic_array_get_next_time_domain_frame

    #define NUM_COMPLEX_PARTS 2 // .re and .im (using a define to distingush between "other 2")
    #define NUM_FREQ_SPECTRA  2 // after FFT if real signal input as tow sequences in .re and .im

    // From the PDF doc XM010267
    // 48 kHz, 24 kHz, 16 kHz, 12 kHz and 8 kHz output sample rate by default (3.072MHz PDM clock)
    // Configurable frame size from 1 sample to 8192 samples plus 50% overlapping frames option,
    // chapter 11 "Four Channel Decimator"
    //
    // 96 kHz divided by 2, 4, 6, 8 or 12. See "fir_coefs.h" and "fir_coefs.xc" in lib_mic_array
    #if (DECIMATION_FACTOR == 2)
        // THIS IS THE ONLY ONE I HAVE THE CORRECT CODE FOR (as of 17Dec2021)
        #define COEF_ARRAYS             g_third_stage_div_2_fir  // [126]
        #define SAMPLING_FREQUENCY_HZ   48000                    // 48 kHz =DAC_OUTPUT_SAMPLE_FREQUENCY_HZ  Observe TEST_SINE_480HZ.
        #define USE_EVERY_N_SAMPLE      6                        // SAMPLES_BUF_DIM == 264, even 256 is too much, 128 works
        #define FIR_GAIN_COMPENSATION   FIR_COMPENSATOR_DIV_2
        //
        //      FIRST_PART               LAST_PART
        //      ------------------------|------------------------ 1024 NUM_MIC_SAMPLES_VAL
        //
        //        (.re)     ------------------------              512 first part
        //                            TO_FFT                      NUM_FFT_POINTS_COMPLEX
        //        (.im)     ------------------------              512 left part
        //
        //             FIRST_FREQ               LAST_FREQ         FIRST_PART and LAST_PART individual spectra
        //            ------------    .re      -----------        256 + 256
        //              FROM_FFT                 FROM FFT         NUM_FREQ_POINTS_COMPLEX
        //            ------------    .im      -----------        256 + 256

        #define NUM_MIC_SAMPLES_LOG2         10 // power of 2
                                                // 10 = 1024, ie. sequence of 1024 real values
                                                // Just some value so far

        // Some macros (like FFT_SINE()) won't allow NUM_MIC_SAMPLES_LOG2 or expressions
        //
        #define NUM_MIC_SAMPLES        1024
        #define NUM_FFT_POINTS_COMPLEX  512 // 1024 / NUM_COMPLEX_PARTS
        #define NUM_FREQ_POINTS_COMPLEX 256 //  512 / NUM_FREQ_SPECTRA
        #define NUM_FREQ_POINTS_REAL    256 //  Same as above

    #elif (DECIMATION_FACTOR == 4)
        #define COEF_ARRAYS             g_third_stage_div_4_fir  // [252]
        #define SAMPLING_FREQUENCY_HZ   24000                    // 24 kHz =DAC_OUTPUT_SAMPLE_FREQUENCY_HZ
        #define USE_EVERY_N_SAMPLE      1
        #define FIR_GAIN_COMPENSATION   FIR_COMPENSATOR_DIV_4
        #define NUM_MIC_SAMPLES_LOG2    10                       // Just some value so far
    #elif (DECIMATION_FACTOR == 6) // 220
        #define COEF_ARRAYS             g_third_stage_div_6_fir  // [378]
        #define SAMPLING_FREQUENCY_HZ   16000                    // 16 kHz =DAC_OUTPUT_SAMPLE_FREQUENCY_HZ
        #define USE_EVERY_N_SAMPLE      2
        #define FIR_GAIN_COMPENSATION   FIR_COMPENSATOR_DIV_6
        #define NUM_MIC_SAMPLES_LOG2    10                                          // power of 2
                                                                                    // 10 = 1024, ie. sequence of 1024 real values
                                                                                    // Just some value so far
        #define NUM_MIC_SAMPLES_VAL     1024                                        // Some macros (like FFT_SINE()) won't allow NUM_MIC_SAMPLES_LOG2
        #define NUM_FFT_POINTS_COMPLEX  (NUM_MIC_SAMPLES_VAL / NUM_COMPLEX_PARTS)   // 512
        #define NUM_FREQ_POINTS_COMPLEX (NUM_FFT_POINTS_COMPLEX / NUM_FREQ_SPECTRA) // 256
        #define NUM_FREQ_POINTS_REAL    (NUM_FREQ_POINTS_COMPLEX)                   // 256

    #elif (DECIMATION_FACTOR == 8)
        #define COEF_ARRAYS             g_third_stage_div_8_fir  // [504]
        #define SAMPLING_FREQUENCY_HZ   12000                    // 12 kHz =DAC_OUTPUT_SAMPLE_FREQUENCY_HZ
        #define USE_EVERY_N_SAMPLE      1
        #define FIR_GAIN_COMPENSATION   FIR_COMPENSATOR_DIV_8
        #define NUM_MIC_SAMPLES_LOG2    8                        // Just some value so far
    #elif (DECIMATION_FACTOR == 12)
        #define COEF_ARRAYS             g_third_stage_div_12_fir // [756]
        #define SAMPLING_FREQUENCY_HZ   8000                     // 8 kHz =DAC_OUTPUT_SAMPLE_FREQUENCY_HZ
        #define USE_EVERY_N_SAMPLE      1
        #define FIR_GAIN_COMPENSATION   FIR_COMPENSATOR_DIV_12
        #define NUM_MIC_SAMPLES_LOG2    8                        // Just some value so far
    #else
        #error
    #endif

#else
    #error NESTED .h FILE
#endif
