/*
 * port_tile0_task.xc
 *
 * None of the ports on the xCORE MICROPHONE ARRAY board's expansien header are on tile[1]
 * From tasks on tile[1] use this to excercise port(s)
 *
 *  Created on: 7. apr. 2022
 *      Author: oyvindteig
 */

#define INCLUDES
#ifdef INCLUDES
    #include <xs1.h>
    #include <platform.h> // tile
    #include <timer.h>    // delay_milliseconds(200), XS1_TIMER_HZ etc
    #include <stdint.h>   // uint8_t
    #include <stdio.h>    // printf
    #include <xscope.h>   // xScope logging
    #include <string.h>   // memcpy
    #include <xccompat.h> // REFERENCE_PARAM(my_app_ports_t, my_app_ports) -> my_app_ports_t &my_app_ports
    #include <iso646.h>   // not etc.
    #include <xassert.h>

    #include "_version.h" // First this..
    #include "_globals.h" // ..then this

    #include "port_tile0_task.h"

    #define DO_DEBUG_PRINT         0 // 0 has consequences if (USE_XSCOPE == 1) and amy timing at all needs to be met
    #define DO_DEBUG_PRINT_SPECIAL 0
    #define DO_WARNINGS            1
    #include "_print_macros_xc.h"
#endif



[[distributable]] // but [[combined]] here since on another tile
void port_tile0_task (
        server  port_commands_if if_port_commands,
        out port                  p_scope_violet)
{
    unsigned cnt = 0;

    while (1) {
        select {
            case if_port_commands.write_port (const port_e value) : {
                // Page 63 of XMOS Programming Guide
                //     In general, when outputting to an n-bit port,
                //     the least significant n bits of the output value
                //     are driven on the pins and the rest are ignored.
                //
                p_scope_violet <: value; // bit0 goes out, since one-bit port

                debug_print ("P%u %u\n", value, cnt);
                cnt++;
            } break;
        }
    }
}
